package com.yidianling.dynamic.trendsDetail;

import com.ydl.ydlcommon.mvp.base.IView;
import com.yidianling.dynamic.model.CommentBean;
import com.yidianling.dynamic.model.Reply;
import com.yidianling.dynamic.model.TrendsDetailInfoBean;
import com.ydl.ydlcommon.data.http.BaseResponse;

import java.util.List;

/**
 * Created by Jim on 2017/10/10 0010.
 */

public interface ITrendsDetailView extends IView {
    void showLoadingView(String message);

    void hideRefreshProgress();

    void hideLoadingView();

    void showTrendsBodyContent(TrendsDetailInfoBean.TrendBody trendBody);

    void showTrendsNotExsitView();

    void showTrendsLoadErrorView();

    void showZanList(List<TrendsDetailInfoBean.ZanImg> zanImgList);

    void showCommentsList(List<CommentBean> commentsBean);

    void showCommentsLoadError();

    void showLikedView();

    void showUnLikeView();

    void showCommentsItemLikeStatus(int status);

    void showFousChangeView();

    void showReportContentView(BaseResponse response, int answerId, String commentContent);

    void refreshCommentListAfterComment(BaseResponse<Reply> replyBaseResponse, int type, String content, String replyContent, String toName);

    void showDeleteReplyOrTrendView(BaseResponse<Object> response, int type, int position);

    void showToast(String msg);

    void showAds(List<TrendsDetailInfoBean.Ad> adList);

    void showSilencedDialog(String tips, String url);
}
